LowLevel

Struct LowLevel 

pub struct LowLevel<M: Model, I: Interface> { /* private fields */ }
LowLevel is a low-level interface to EVE controllers which matches the primitive operations used in Programmers Guides for the various EVE controllers.

This is slightly higher-level than the Interface trait, providing size-specific memory accesses, but doesn’t have any special knowledge about the memory map or command set of any particular EVE implementation.

This struct tracks a “cursor” for appending display list entries using the dl method. Use dl_reset to reset that cursor to the beginning of display list memory, which you’ll typically (but not necessarily) do after writing REG_DLSWAP to swap the display list double buffer. LowLevel doesn’t manage display list buffer swapping itself, only the cursor for the next dl call.

Implementations

Source

impl<M: Model, I: Interface> LowLevel<M, I>

pub fn new(interface: I) -> Self

pub fn take_interface(self) -> I

Consumes the LowLevel object and returns the interface it was originally created with.

pub fn borrow_interface<'a>(&'a mut self) -> &'a mut I

pub fn wr8<R: HostAccessible>(&mut self, addr: Ptr<R>, v: u8) -> Result<(), I>

pub fn wr16<R: HostAccessible>(&mut self, addr: Ptr<R>, v: u16) -> Result<(), I>

pub fn wr32<R: HostAccessible>(&mut self, addr: Ptr<R>, v: u32) -> Result<(), I>

pub fn wr8s<R: HostAccessible>( &mut self, addr: Ptr<R>, v: &[u8], ) -> Result<(), I>

pub fn rd8<R: HostAccessible>(&mut self, addr: Ptr<R>) -> Result<u8, I>

pub fn rd16<R: HostAccessible>(&mut self, addr: Ptr<R>) -> Result<u16, I>

pub fn rd32<R: HostAccessible>(&mut self, addr: Ptr<R>) -> Result<u32, I>

pub fn rd8s<R: HostAccessible>( &mut self, addr: Ptr<R>, into: &mut [u8], ) -> Result<(), I>

pub fn main_mem_ptr(&self, offset: u32) -> Ptr<M::MainMem>

pub fn reg_ptr(&self, reg: Register) -> Ptr<M::RegisterMem>

pub fn host_command(&mut self, cmd: HostCmd, a0: u8, a1: u8) -> Result<(), I>

pub fn dl_reset(&mut self)

pub fn dl(&mut self, cmd: DLCmd) -> Result<(), I>